@@ -8,6 +8,7 @@ fragment ProgramTrackAction on ProgramTrackAction {
     sourceProgramModule {
         id
     }
+    data
     waitsForFeedback
 }
 """
@@ -21,6 +22,10 @@ class ProgramTrackAction(Node):
     def waits_for_feedback(self) -> bool:
         return self._data["waitsForFeedback"]
 
+    @property
+    def data(self):
+        return self._data["data"]
+
     @property
     def module(self):
         if not self._data["sourceProgramModule"]:
@@ -28,8 +33,7 @@ class ProgramTrackAction(Node):
 
         return ProgramModule(self._data["sourceProgramModule"], self._context)
 
-    @property
-    def responses(self):
+    async def list_responses(self):
         from .program_track_action_response import (
             ProgramTrackActionResponse,
             programTrackActionResponseFragment,
@@ -54,7 +58,7 @@ class ProgramTrackAction(Node):
 
         variables = {}
         variables["programTrackActionId"] = self.id
-        response = self._execute(query, variables)
+        response = await self._execute(query, variables)
 
         responses: list[ProgramTrackActionResponse] = []
         for edge in response["programTrackAction"]["responses"]["edges"]:
