@@ -1,3 +1,6 @@
+from typing import Optional
+
+
 class BlocksActionBuilder(object):
     def __init__(self):
         super().__init__()
@@ -23,23 +26,36 @@ class BlocksActionBuilder(object):
     def add_note(self, text: str):
         return self.add_block({"type": "note", "text": text,})
 
-    def add_text_field(self, title: str, required: bool = False):
-        return self.add_block({"type": "textField", "title": title, "required": required,})
+    def add_text_field(self, title: str, required: bool = False, id: Optional[str] = None):
+        return self.add_block(
+            {"type": "textField", "title": title, "required": required, "id": id,}
+        )
 
-    def add_image_field(self, title: str, required: bool = False):
-        return self.add_block({"type": "imageField", "title": title, "required": required,})
+    def add_image_field(self, title: str, required: bool = False, id: Optional[str] = None):
+        return self.add_block(
+            {"type": "imageField", "title": title, "required": required, "id": id,}
+        )
 
-    def add_date_time_field(self, title: str, required: bool = False):
-        return self.add_block({"type": "dateTimeField", "title": title, "required": required,})
+    def add_date_time_field(self, title: str, required: bool = False, id: Optional[str] = None):
+        return self.add_block(
+            {"type": "dateTimeField", "title": title, "required": required, "id": id,}
+        )
 
     def add_scale_field(
-        self, title: str, required: bool = False, min: int = 0, max: int = 10, step: int = 1,
+        self,
+        title: str,
+        required: bool = False,
+        min: int = 0,
+        max: int = 10,
+        step: int = 1,
+        id: Optional[str] = None,
     ):
         return self.add_block(
             {
                 "type": "scaleField",
                 "title": title,
                 "required": required,
+                "id": id,
                 "min": min,
                 "max": max,
                 "step": step,
@@ -47,20 +63,33 @@ class BlocksActionBuilder(object):
         )
 
     def add_multiple_choice_field(
-        self, title: str, required: bool = False, choices: list = [],
+        self, title: str, required: bool = False, choices: list = [], id: Optional[str] = None
     ):
         return self.add_block(
-            {"type": "scaleField", "title": title, "required": required, "choices": choices,}
+            {
+                "type": "scaleField",
+                "title": title,
+                "required": required,
+                "id": id,
+                "choices": choices,
+            }
         )
 
     def add_number_field(
-        self, title: str, required: bool = False, min: int = 0, max: int = 10, step: int = 1,
+        self,
+        title: str,
+        required: bool = False,
+        min: int = 0,
+        max: int = 10,
+        step: int = 1,
+        id: Optional[str] = None,
     ):
         return self.add_block(
             {
                 "type": "numberField",
                 "title": title,
                 "required": required,
+                "id": id,
                 "min": min,
                 "max": max,
                 "step": step,
